@@ -2,6 +2,7 @@
 
 import errno
 import exceptions
+import locale
 import sys
 import struct
 
@@ -38,8 +39,13 @@ class ACEFileWriteException(ACEFileException): #{{{1
     def __init__(self, errmsg):
         ACEFileException.__init__(self, 'Error writing dictionary', errmsg)
 
+class ACEFileDecodeException(ACEFileException): #{{{1
+    def __init__(self):
+        ACEFileException.__init__(self, 'Error decoding string', 'Encoding tried was %s' % locale.getdefaultlocale()[1])
+
 class ACEFile(): #{{{1
     _dicts = {}
+    _encoding = locale.getdefaultlocale()[1]
 
     def __init__(self): #{{{2
         self.read()
@@ -59,10 +65,21 @@ class ACEFile(): #{{{1
         size = 0
 
         for dictEntry in self._dicts[dictLanguage]:
-            size += len(dictEntry.toLocal8Bit()) + 1
+            size += len(self._fromQString(dictEntry)) + 1
 
         return size
 
+    def _fromQString(self, strng): #{{{2
+        return unicode(strng.toUtf8(), 'utf-8').encode(self._encoding)
+
+    def _toQString(self, strng): #{{{2
+        try:
+            qStrng = unicode(strng, self._encoding)
+        except Exception, e:
+            raise ACEFileDecodeException
+
+        return qStrng
+
     def _intToBytes(self, val, count): #{{{2
         hex = "%%0%dx" % (2 * count) % val
         bitstream = ''
@@ -96,10 +113,8 @@ class ACEFile(): #{{{1
             i += 1
 
     def _readEntry(self, file): #{{{2
-        codec = QTextCodec.codecForLocale()
         entryLength = self._bytesToInt(file.read(1))
-        entryString = codec.toUnicode(file.read(entryLength))
-#        entryString = QString.fromLocal8Bit(file.read(entryLength))
+        entryString = self._toQString(file.read(entryLength))
 
         return entryString
 
@@ -123,8 +138,9 @@ class ACEFile(): #{{{1
         return newBuffer
 
     def _writeEntry(self, file, entryString): #{{{2
-        file.write(self._intToBytes(len(entryString), 1))
-        file.write(entryString)
+        encEntryString = self._fromQString(entryString)
+        file.write(self._intToBytes(len(encEntryString), 1))
+        file.write(encEntryString)
 
     def _writeHeader(self, file, dictOrder): #{{{2
         dataSize = self._calculateDataSize()
@@ -193,7 +209,7 @@ class ACEFile(): #{{{1
 
         for dictLanguage in dictOrder:
             for entryString in self._dicts[dictLanguage]:
-                self._writeEntry(file, entryString.toLocal8Bit())
+                self._writeEntry(file, entryString)
 
         self._writePadding(file, fileSize)
 
