@@ -11,7 +11,7 @@ from PyQt4.QtGui   import QAbstractItemView, QComboBox, QDialog, \
                           QVBoxLayout, QWidget
 from ACE_file      import ACEFile;
 
-version = '0.0.5'
+version = '0.0.6'
 
 langLookup = {
     3: 'English (United Kingdom)',
@@ -73,7 +73,7 @@ class ACEMainWindow(QWidget): #{{{1
         self.setMinimumSize(800, 480)
         self.setWindowTitle('AutoComplete Editor')
 
-        self._settings = QSettings('Robin Hill', 'Auto-Complete Editor')
+        self._settings = QSettings('Auto-Complete Editor', 'Auto-Complete Editor')
 
         QHBoxLayout(self)
 
